<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://codingfix.com
 * @since      1.0.0
 *
 * @package    Cfx_Language_Switcher_For_Transposh
 * @subpackage Cfx_Language_Switcher_For_Transposh/public
 */

/**
 * if Transposh is not installed we show an error message on activation
 */
if (!file_exists(WP_PLUGIN_DIR . '/transposh-translation-filter-for-wordpress/core/utils.php')) {
  die("Language Switcher for Transposh can't be activated because Transposh plugin can't be found in WordPress plugins directory. Please, install Transposh plugin before to activate Language Switcher for Transposh. Thank you.");
}
require_once WP_PLUGIN_DIR . '/transposh-translation-filter-for-wordpress/core/utils.php';
/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Cfx_Language_Switcher_For_Transposh
 * @subpackage Cfx_Language_Switcher_For_Transposh/public
 * @author     Marco Gasi <codingfix@codingfix.com>
 */
class Cfx_Language_Switcher_For_Transposh_Public
{

  /**
   * The ID of this plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      string    $plugin_name    The ID of this plugin.
   */
  private $plugin_name;

  /**
   * The version of this plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      string    $version    The current version of this plugin.
   */
  private $version;

  /**
   * The options of this plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      array    $options    The options of this plugin.
   */
  private $options;

  /**
   * The english flag which will be used by this plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      string    $en_flag    The english flag which will be used by this plugin..
   */
  private $en_flag;

  /**
   * The path of the flag icons used by this plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      string    $flag_path    The path of the flag icons used by this plugin.
   */
  private $flag_path;

  /**
   * The options of Transposh Translation Filter plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      array    $transposh_options    The options of Transposh Translation Filter plugin.
   */
  private $transposh_options;

  /**
   * The default language set in Transposh Translation Filter plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      string    $default_lang    The default language set in Transposh Translation Filter plugin.
   */
  private $default_lang;

  /**
   * The options of this plugin.
   *
   * @since    1.0.0
   * @access   private
   * @var      array    $used_languages    The languages actually used in current website.
   */
  private $used_languages;


  /**
   * Initialize the class and set its properties.
   *
   * @since    1.0.0
   * @param      string    $plugin_name       The name of the plugin.
   * @param      string    $version    The version of this plugin.
   */
  public function __construct($plugin_name, $version)
  {

    $this->plugin_name = $plugin_name;
    $this->version = $version;
    $this->options = get_option('cfxlsft_options');
    $this->en_flag = $this->get_en_flag();
    $this->flag_path = $this->get_flag_path();
    $this->transposh_options = get_option(TRANSPOSH_OPTIONS);
    $this->default_lang = $this->transposh_options['default_language'];
    $this->used_languages = explode(',', $this->transposh_options['viewable_languages']);

    
  }

  public function get_current_lang()
  {
    $current_lang = transposh_utils::get_language_from_url(
      $_SERVER['REQUEST_URI'],
      isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] != 'off' ? 'https://' : 'http://' .
        $_SERVER['SERVER_NAME']
    );
    if (empty($current_lang)) {
      $current_lang = $this->default_lang;
    }
    return $current_lang;
  }

  /**
   * Register the stylesheets for the public-facing side of the site.
   *
   * @since    1.0.0
   */
  public function enqueue_styles()
  {

    wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/cfx-language-switcher-for-transposh-public.css', array(), $this->version, 'all');
    $style_path = LSFT_PLUGIN_URL . '/assets/styles/flags';
    $style_name = $this->options['flag_style'];
    if ($this->options['switcher_type'] == 'dropdown') {
      $style_path = LSFT_PLUGIN_URL . '/assets/styles/list';
      $style_name = $this->options['list_style'];
      if ($this->this->options['select_as_list'] === 'no') {
        $style_path = LSFT_PLUGIN_URL . '/assets/styles/select';
        $style_name = $this->options['select_style'];
      }
    }
    wp_enqueue_style($this->plugin_name . '-stylable-select', $style_path . '/' . $style_name, array(), $this->version, 'all');
  }

  /**
   * Register the JavaScript for the public-facing side of the site.
   *
   * @since    1.0.0
   */
  public function enqueue_scripts()
  {

    wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/cfx-language-switcher-for-transposh-public.js', array('jquery'), $this->version, false);
  }

  /**
   * Returns the flag which will be used as english flag (UK or USA flag).
   *
   * @since    1.0.0
   */
  public function get_en_flag()
  {
    $en_flag = "gb";
    if ($this->options['flag_type'] == 'tp') {
      $en_flag = "us";
    }
    return $en_flag;
  }

  /**
   * Returns the path to the flag icons depending on the flags chosen by the developer.
   *
   * @since    1.0.0
   */
  public function get_flag_path()
  {
    $flag_path = LSFT_PLUGIN_URL . "/assets/flags";
    if ($this->options['flag_type'] == 'tp') {
      $flag_path = TRANSPOSH_DIR_IMG . '/flags';
    }
    return $flag_path;
  }

  /**
   * Returns the name of the flag icon.
   *
   * @since    1.0.0
   */
  public function get_flag_name($lang)
  {
    if ($lang === 'en') {
      $flag_name = $this->en_flag;
    } else {
      $flag_name = transposh_consts::get_language_flag($lang);
    }
    return $flag_name;
  }

  /**
   * Returns the URL the user will be redirected to when he change the website language.
   *
   * @since    1.0.0
   */
  public function get_target_page($lang)
  {
    $target = get_site_url() . '/' . $lang;
    if ($this->default_lang === $lang) {
      $target = get_site_url();
    }
    return $target;
  }

  /**
   * Returns the markup of the first list item.
   *
   * @since    1.0.0
   */
  public function get_list_first_item_markup()
  {
    $flag_name = $this->get_flag_name($this->get_current_lang());
    $lang_name = ucfirst(transposh_consts::get_language_name($this->get_current_lang()));
    switch ($this->options['custom_list_items']) {
      case 'flag-only':
        $item = "<a class='menu-link' href='#' id='stylable-list-first-item'><img src='$this->flag_path/" . $flag_name . ".png'></a>";
        break;
      case 'text-only':
        $item = "<a class='menu-link' href='#' id='stylable-list-first-item' class='no_translate'>$lang_name</a>";
        break;
      case 'flag-and-text':
        $item = "<a class='menu-link' href='#' id='stylable-list-first-item' class='no_translate' style='background: url($this->flag_path/" . $flag_name . ".png) 0 center no-repeat;'>$lang_name</a>";
        break;
      default:
    }
    return $item;
  }

  /**
   * Returns the markup for the list items.
   *
   * @since    1.0.0
   */
  public function get_list_item_markup($lang, $menu_classes)
  {
    $flag_name = $this->get_flag_name($lang);
    $target = $this->get_target_page($lang);
    $lang_name = ucfirst(transposh_consts::get_language_name($lang));
    switch ($this->options['custom_list_items']) {
      case 'flag-only':
        $item = "<li class='no_translate " . $menu_classes  . "'><a class='menu-link'  href='$target'><img src='$this->flag_path/$flag_name.png'></a></li>";
        break;
      case 'text-only':
        $item = "<li class='no_translate " . $menu_classes  . "'><a class='menu-link'  href='$target'>$lang_name</a></li>";
        break;
      case 'flag-and-text':
        $item = "<li class='no_translate " . $menu_classes  . "' style='background: url($this->flag_path/" . $flag_name . ".png) 0 center no-repeat;'><a class='menu-link'  href='$target'>$lang_name</a></li>";
        break;
      default:
    }
    return $item;
  }

  /**
   * Actually adds the language switcher to the main manu.
   *
   * @since    1.0.0
   */
  public function cfxlsft_add_menu_item($items, $args)
  {
    $menu_classes = str_replace(',', '', $this->options['menu_classes']);
    $menu_locations = explode(',', $this->options['menu_locations']);
    //if we only use one language nothing has to be added
    if (!empty($this->transposh_options['viewable_languages'])) {
      if (count($this->used_languages) > 1) {
        if (in_array($args->theme_location, $menu_locations)) {
          /**DISPLAY FLAGS */
          if ($this->options['switcher_type'] == 'flags') {

            foreach ($this->used_languages as $lang) {
              $flag_name = $this->get_flag_name($lang);
              $target = $this->get_target_page($lang);
              $items .= '<li class="' . $menu_classes  . ' menu-item switch_lang no_translate"><a class="menu-link" href="' . $target . '"><img src="' . $this->flag_path . '/' . $flag_name . '.png" /></a></li>';
            }
            if (get_locale() != $this->transposh_options['default_language']) {

              $user = wp_get_current_user();
              $allowed_roles = array('editor', 'administrator', 'author');
              /**this button will be available only to certain user types */
              if (array_intersect($allowed_roles, $user->roles)) {
                $items .= '<li class="' . $menu_classes . ' menu-item edit_translation no_translate"><a class="menu-link" href="#"> Edit</a></li>';
              }
            }
          } else {
            /** DISPLAY CUSTOM LIST */
            if ($this->options['select_as_list'] == 'yes') {
              $items .= "<li id='stylable-list' class='$menu_classes " . $this->options['custom_list_items'] . "'>";
              $items .= $this->get_list_first_item_markup($menu_classes);
              if (($key = array_search($this->get_current_lang(), $this->used_languages)) !== false) {
                unset($this->used_languages[$key]);
              }
              $items .= "<ul id='lsft-sub-menu'>";
              foreach ($this->used_languages as $lang) {
                $items .= $this->get_list_item_markup($lang, $menu_classes);
              }
              if (get_locale() != $this->options['default_language']) {

                $user = wp_get_current_user();
                $allowed_roles = array('editor', 'administrator', 'author');
                /**this button will be available only to certain user types */
                if (array_intersect($allowed_roles, $user->roles)) {
                  $items .= '<li class="' . $menu_classes . ' edit_translation no_translate"><a class="menu-link" href="#"> Edit</a></li>';
                }
              }
              $items .= '</ul></li>';
            } else {
              /** DISPLAY SELECT */
              $items .= '<li class="menu-item ' . $menu_classes . '"><select id="switch_lang_select" class="stylable-select">';
              foreach ($this->used_languages as $lang) {
                $target = $this->get_target_page($lang);
                $lang_name = ucfirst(transposh_consts::get_language_name($lang));
                if ($lang == $this->get_current_lang()) {
                  $selected = 'selected';
                } else {
                  $selected = '';
                }
                $items .= '<option data-target="' . $target . '" value="' . $lang . '" ' . $selected . ' class="no_translate">' . $lang_name . ' </option>';
              }
              $items .= '</select></li>';
              if (get_locale() != $this->options['default_language']) {

                $user = wp_get_current_user();
                $allowed_roles = array('editor', 'administrator', 'author');
                /**this button will be available only to certain user types */
                if (array_intersect($allowed_roles, $user->roles)) {
                  $items .= '<li class="menu-item ' . $menu_classes . ' edit_translation no_translate"><a class="menu-link" href="#">' . $this->get_current_lang() . ' Edit</a></li>';
                }
              }
            }
          }
        }
      }
    }
    return $items;
  }

  /**
   * Actually actyivate or deactivate the Transposh Translation Editor.
   *
   * @since    1.0.0
   */
  public function cfxlsft_edit_button_action()
  { ?>
    <script type="text/javascript">
      jQuery(document).ready(function($) {
        var urlParam = function(name) {
          var results = new RegExp('[\?&]' + name + '=([^&#]*)')
            .exec(window.location.search);

          return (results !== null) ? results[1] || 0 : false;
        }

        $(document).on('click', '.edit_translation', function(e) {
          e.preventDefault();
          var currentUrl = window.location.href;
          var currentOrigin = window.location.origin;
          var currentPath = window.location.pathname;
          var param = urlParam('tpedit');
          var newUrl = '';
          if (param === false) {
            newUrl = currentOrigin + currentPath + '?tpedit=1';
            $(this).attr('href', newUrl);
          } else {
            newUrl = currentOrigin + currentPath;
            $(this).attr('href', newUrl);
          }
          window.location.href = newUrl;
        })

      })
    </script>
<?php
  }
}
